@@ -1,21 +1,12 @@
-# -*- coding: utf-8 -*-
 import re
-import sys
-
+from html import escape
 from math import ceil
 from numbers import Number
+from urllib.parse import parse_qsl
 
 from py3status.composite import Composite
 from py3status.constants import COLOR_NAMES, COLOR_NAMES_EXCLUDED
 
-try:
-    from urllib.parse import parse_qsl
-except ImportError:
-    from urlparse import parse_qsl
-
-
-python2 = sys.version_info < (3, 0)
-
 
 def expand_color(color, default=None, passthrough=False, block=None):
     """
@@ -69,8 +60,6 @@ class Formatter:
         Tokenizing is resource intensive so we only do it once and cache it
         """
         if format_string not in self.format_string_cache:
-            if python2 and isinstance(format_string, str):
-                format_string = format_string.decode("utf-8")
             tokens = list(re.finditer(self.reg_ex, format_string))
             self.format_string_cache[format_string] = tokens
         return self.format_string_cache[format_string]
@@ -133,7 +122,7 @@ class Formatter:
         for token in self.tokens(format_string):
             if token.group("key") in placeholders:
                 output.append(
-                    "{%s%s}" % (placeholders[token.group("key")], token.group("format"))
+                    "{{{}{}}}".format(placeholders[token.group("key")], token.group("format"))
                 )
                 continue
             elif token.group("command"):
@@ -158,11 +147,9 @@ class Formatter:
                                     value_ = condition.value
                                 else:
                                     value_ = ""
-                                value = "{}{}{}{}".format(
-                                    not_, variable, condition_, value_
-                                )
+                                value = "{}{}{}{}".format(not_, variable, condition_, value_)
                         if value:
-                            items.append("{}={}".format(key, value))
+                            items.append(f"{key}={value}")
                         else:
                             items.append(key)
 
@@ -172,7 +159,7 @@ class Formatter:
                     continue
             value = token.group(0)
             output.append(value)
-        return u"".join(output)
+        return "".join(output)
 
     def update_placeholder_formats(self, format_string, placeholder_formats):
         """
@@ -186,14 +173,11 @@ class Formatter:
                 and (not token.group("format"))
                 and token.group("key") in placeholder_formats
             ):
-                output.append(
-                    "{%s%s}"
-                    % (token.group("key"), placeholder_formats[token.group("key")])
-                )
+                output.append(f"{{{token.group('key')}{placeholder_formats[token.group('key')]}}}")
                 continue
             value = token.group(0)
             output.append(value)
-        return u"".join(output)
+        return "".join(output)
 
     def build_block(self, format_string):
         """
@@ -256,10 +240,6 @@ class Formatter:
         param_dict, attributes of the supplied module, or provided via calls to
         the attr_getter function.
         """
-        # fix python 2 unicode issues
-        if python2 and isinstance(format_string, str):
-            format_string = format_string.decode("utf-8")
-
         if param_dict is None:
             param_dict = {}
 
@@ -293,9 +273,7 @@ class Formatter:
                 if param.text():
                     param = param.copy()
                 else:
-                    param = u""
-            elif python2 and isinstance(param, str):
-                param = param.decode("utf-8")
+                    param = ""
             return param
 
         # render our processed format
@@ -326,7 +304,7 @@ class Placeholder:
         """
         return the correct value for the placeholder
         """
-        value = "{%s}" % self.key
+        value = f"{{{self.key}}}"
         try:
             value = value_ = get_params(self.key)
             if self.format.startswith(":"):
@@ -339,21 +317,23 @@ class Placeholder:
                 # no remaining digits following it.  If the parameter cannot
                 # be successfully converted then the format will be removed.
                 try:
+                    if "escape" in self.format:
+                        value = escape(value)
                     if "ceil" in self.format:
-                        value = int(ceil(float(value)))
+                        value = ceil(float(value))
                     if "f" in self.format:
                         value = float(value)
                     if "g" in self.format:
                         value = float(value)
                     if "d" in self.format:
                         value = int(float(value))
-                    output = u"{[%s]%s}" % (self.key, self.format)
+                    output = f"{{[{self.key}]{self.format}}}"
                     value = output.format({self.key: value})
                     value_ = float(value)
                 except ValueError:
                     pass
             elif self.format.startswith("!"):
-                output = u"{%s%s}" % (self.key, self.format)
+                output = f"{{{self.key}{self.format}}}"
                 value = value_ = output.format(**{self.key: value})
 
             if block.commands.not_zero:
@@ -371,14 +351,14 @@ class Placeholder:
         return valid, value, enough
 
     def __repr__(self):
-        return "<Placeholder {%s}>" % self.repr()
+        return f"<Placeholder {{{self.repr()}}}>"
 
     def repr(self):
         if self.format:
-            value = "%s%s" % (self.key, self.format)
+            value = f"{self.key}{self.format}"
         else:
             value = self.key
-        return "{%s}" % value
+        return f"{{{value}}}"
 
 
 class Literal:
@@ -390,7 +370,7 @@ class Literal:
         self.text = text
 
     def __repr__(self):
-        return "<Literal %s>" % self.text
+        return f"<Literal {self.text}>"
 
     def repr(self):
         return self.text
@@ -512,9 +492,7 @@ class BlockConfig:
             self._if = Condition(_if)
         self._set_int(commands, "max_length")
         self._set_int(commands, "min_length")
-        self.color = expand_color(
-            commands.get("color"), passthrough=True, block=self.color
-        )
+        self.color = expand_color(commands.get("color"), passthrough=True, block=self.color)
 
         self.not_zero = "not_zero" in commands or self.not_zero
         self.show = "show" in commands or self.show
@@ -538,7 +516,6 @@ class Block:
     """
 
     def __init__(self, parent, base_block=None, py3_wrapper=None):
-
         self.base_block = base_block
         self.commands = BlockConfig(parent)
         self.content = []
@@ -570,13 +547,11 @@ class Block:
         option and return it to the user.
         """
         base_block = self.base_block or self
-        self.next_block = Block(
-            self.parent, base_block=base_block, py3_wrapper=self.py3_wrapper
-        )
+        self.next_block = Block(self.parent, base_block=base_block, py3_wrapper=self.py3_wrapper)
         return self.next_block
 
     def __repr__(self):
-        return "<Block %s>" % self.repr()
+        return f"<Block {self.repr()}>"
 
     def repr(self):
         my_repr = [x.repr() for x in self.content]
@@ -625,12 +600,8 @@ class Block:
                 valid = valid or sub_valid
         if not valid:
             if self.next_block:
-                valid, output = self.next_block.render(
-                    get_params, module, _if=self.commands._if
-                )
-            elif self.parent is None and (
-                (not self.next_block and enough) or self.base_block
-            ):
+                valid, output = self.next_block.render(get_params, module, _if=self.commands._if)
+            elif self.parent is None and ((not self.next_block and enough) or self.base_block):
                 valid = True
             else:
                 output = []
@@ -638,8 +609,8 @@ class Block:
         # clean
         color = self.commands.color
         if color and color[0] != "#":
-            color_name = "color_%s" % color
-            threshold_color_name = "color_threshold_%s" % color
+            color_name = f"color_{color}"
+            threshold_color_name = f"color_threshold_{color}"
             # substitute color
             color = (
                 getattr(module, color_name, None)
@@ -649,28 +620,20 @@ class Block:
             if color == "hidden":
                 return False, []
 
-        text = u""
+        text = ""
         out = []
         if isinstance(output, str):
             output = [output]
 
         # merge as much output as we can.
-        # we need to convert values to unicode for concatenation.
-        if python2:
-            conversion = unicode  # noqa
-            convertibles = (str, bool, int, float, unicode)  # noqa
-        else:
-            conversion = str
-            convertibles = (str, bool, int, float, bytes)
-
         first = True
         last_block = None
         for index, item in enumerate(output):
             is_block = isinstance(item, Block)
             if not is_block and item:
                 last_block = None
-            if isinstance(item, convertibles) or item is None:
-                text += conversion(item)
+            if isinstance(item, (str, bool, int, float, bytes)) or item is None:
+                text += str(item)
                 continue
             elif text:
                 if not first and (text == "" or out and out[-1].get("color") == color):
@@ -680,7 +643,7 @@ class Block:
                     if color:
                         part["color"] = color
                     out.append(part)
-                text = u""
+                text = ""
             if isinstance(item, Composite):
                 if color:
                     item.composite_update(item, {"color": color}, soft=True)
@@ -689,8 +652,8 @@ class Block:
                 # if this is a block then likely it is soft.
                 if not out:
                     continue
-                for x in range(index + 1, len(output)):
-                    if output[x] and not isinstance(output[x], Block):
+                for other in output[index + 1 :]:
+                    if other and not isinstance(other, Block):
                         valid, _output = item.render(get_params, module, _if=True)
                         if _output and _output != last_block:
                             last_block = _output
@@ -720,7 +683,7 @@ class Block:
                 if min_length:
                     min_length -= len(item["full_text"])
             if min_length > 0:
-                out[0]["full_text"] = u" " * min_length + out[0]["full_text"]
+                out[0]["full_text"] = " " * min_length + out[0]["full_text"]
                 min_length = 0
 
         return valid, out
