@@ -83,13 +83,11 @@ waiting
 {'color': '#FF0000', 'full_text': '.. cmus: waiting for user input'}
 """
 
-
 STRING_NOT_INSTALLED = "not installed"
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     button_next = None
@@ -115,7 +113,7 @@ class Py3status:
     def _seconds_to_time(self, value):
         m, s = divmod(int(value), 60)
         h, m = divmod(m, 60)
-        time = "%d:%02d:%02d" % (h, m, s)
+        time = f"{h}:{m:02d}:{s:02d}"
         return time.lstrip("0").lstrip(":")
 
     def _get_cmus_data(self):
@@ -162,8 +160,7 @@ class Py3status:
         return temporary
 
     def cmus(self):
-        """
-        """
+        """ """
         is_paused = is_playing = is_stopped = None
         cached_until = self.sleep_timeout
         color = self.py3.COLOR_BAD
@@ -196,7 +193,7 @@ class Py3status:
                     is_playing=is_playing,
                     is_started=is_started,
                     is_stopped=is_stopped,
-                    **data
+                    **data,
                 ),
             ),
         }
