@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-"""
+r"""
 Display NumLock, CapsLock, and ScrLock keys.
 
 Configuration parameters:
@@ -38,15 +37,14 @@ no_locks
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     cache_timeout = 1
     format = (
-        "[\?if=num_lock&color=good NUM|\?color=bad NUM] "
-        "[\?if=caps_lock&color=good CAPS|\?color=bad CAPS] "
-        "[\?if=scroll_lock&color=good SCR|\?color=bad SCR]"
+        r"[\?if=num_lock&color=good NUM|\?color=bad NUM] "
+        r"[\?if=caps_lock&color=good CAPS|\?color=bad CAPS] "
+        r"[\?if=scroll_lock&color=good SCR|\?color=bad SCR]"
     )
 
     def post_config_hook(self):
@@ -69,7 +67,7 @@ class Py3status:
     def keyboard_locks(self):
         xset_data = self.py3.command_output("xset q")
         for k, v in self.keyring.items():
-            self.locks[k] = "on" in xset_data.split("%s Lock:" % v)[1][0:6]
+            self.locks[k] = "on" in xset_data.split(f"{v} Lock:")[1][0:6]
 
         return {
             "cached_until": self.py3.time_in(self.cache_timeout),
