@@ -72,7 +72,6 @@ stopped
 {'color': '#FF0000', 'full_text': '[] moc'}
 """
 
-
 STRING_NOT_INSTALLED = "not installed"
 
 
@@ -144,7 +143,7 @@ class Py3status:
                     is_playing=is_playing,
                     is_started=is_started,
                     is_stopped=is_stopped,
-                    **data
+                    **data,
                 ),
             ),
         }
