@@ -7,14 +7,13 @@ to define the button parameters in your config.
 
 Configuration parameters:
     button_next: mouse button to play the next entry (default None)
-    button_next_player: (Experimental) mouse button to switch next player in list (Same status as top player) (default None)
-    button_prev_player: (Experimental) mouse button to switch previous player in list (Same status as top player) (default None)
+    button_next_player: mouse button to switch next player in list (Same status as top player) (default None)
+    button_prev_player: mouse button to switch previous player in list (Same status as top player) (default None)
     button_previous: mouse button to play the previous entry (default None)
     button_stop: mouse button to stop the player (default None)
     button_switch_to_top_player: mouse button to switch to top player (default None)
     button_toggle: mouse button to toggle between play and pause mode (default 1)
     cache_timeout: time (s) between Position update (default 0.5)
-    format: see placeholders below
     format: display format for this module
         (default '[{artist} - ][{title}] {previous} {toggle} {next}')
     format_none: define output if no player is running (default 'no player running')
@@ -24,7 +23,6 @@ Configuration parameters:
     icon_previous: specify icon for previous button (default u'\u25c3')
     icon_stop: specify icon for stop button (default u'\u25a1')
     max_width: maximum status length (default None)
-    player_hide_non_canplay: Experimental. Used to hide chrome/chromium players on idle state. Add 'chromium' into list and try. (default [])
     player_priority: priority of the players.
         Keep in mind that the state has a higher priority than
         player_priority. So when player_priority is "[mpd, bomi]" and mpd is
@@ -61,7 +59,8 @@ Color options:
 
 Requires:
     mpris2: Python usable definiton of MPRIS2
-    dbus: Python bindings for dbus
+    dbus-python: Python bindings for dbus
+    PyGObject: Python bindings for GObject Introspection
 
 Tested players:
     bomi: powerful and easy-to-use gui multimedia player based on mpv
@@ -101,6 +100,7 @@ SAMPLE OUTPUT
     {'color': '#00FF00', 'full_text': u'Happy Mondays - Fat Lady Wrestlers'}
 ]
 """
+
 import re
 import sys
 from datetime import timedelta
@@ -149,7 +149,6 @@ class Player:
         self._player_shortname = name_from_id
         self._dPlayer = dPlayer(dbus_interface_info={"dbus_uri": player_id})
         self._full_name = f"{self._identity} {self._identity_index}"
-        self._hide_non_canplay = self._player_shortname in self.parent.player_hide_non_canplay
 
         self._placeholders = {
             "player": self._identity,
@@ -345,7 +344,7 @@ class Player:
 
     @property
     def hide(self):
-        return self._hide_non_canplay and not self._can.get("CanPlay")
+        return not self._can.get("CanPlay")
 
     @property
     def id(self):
@@ -379,12 +378,21 @@ class Py3status:
     icon_previous = "\u25c3"
     icon_stop = "\u25a1"
     max_width = None
-    player_hide_non_canplay = []
     player_priority = []
     state_pause = "\u25eb"
     state_play = "\u25b7"
     state_stop = "\u25a1"
 
+    class Meta:
+        deprecated = {
+            'remove': [
+                {
+                    'param': 'player_hide_non_canplay',
+                    'msg': 'obsolete because we now hide all non canplay players',
+                },
+            ],
+        }
+
     def post_config_hook(self):
         self._name_owner_change_match = None
         self._kill = False
@@ -482,7 +490,7 @@ class Py3status:
                 self._format_contains_control_buttons = True
                 self._used_can_properties.append(value["clickable"])
 
-        if len(self.player_hide_non_canplay) and "CanPlay" not in self._used_can_properties:
+        if "CanPlay" not in self._used_can_properties:
             self._used_can_properties.append("CanPlay")
 
         self._format_contains_time = self.py3.format_contains(self.format, "time")
@@ -565,7 +573,7 @@ class Py3status:
         name_from_id = player_id_parts_list[3]
 
         identity = None
-        if name_from_id != "chromium":
+        if name_from_id not in ["chromium", "kdeconnect"]:
             identity = self._identity_cache.get(name_from_id)
 
         if not identity:
