@@ -47,15 +47,14 @@ mode
 {'color': '#00FF00', 'full_text': u'\u25cf'}
 """
 
-from time import time
+import time
 
 URL_GEO_OLD_DEFAULT = "http://ip-api.com/json"
 URL_GEO_NEW_DEFAULT = "https://ifconfig.co/json"
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     button_refresh = 2
@@ -120,7 +119,7 @@ class Py3status:
 
     def whatismyip(self):
         # refresh
-        current_time = time()
+        current_time = time.monotonic()
         refresh = current_time >= self.idle_time
 
         # time
