@@ -45,10 +45,12 @@ class Ipc:
 
     def compatibility(self, window_properties):
         # specify width to truncate title with ellipsis
-        if self.parent.max_width:
-            title = window_properties["title"]
-            if title and len(title) > self.parent.max_width:
+        title = window_properties.get("title", "")
+        if title:
+            if self.parent.max_width and len(title) > self.parent.max_width:
                 window_properties["title"] = title[: self.parent.max_width - 1] + "…"
+        else:
+            window_properties["title"] = ""
 
         return window_properties
 
@@ -178,10 +180,7 @@ class Msg(Ipc):
             if (
                 focused["border"] == "normal"
                 or focused["type"] == "workspace"
-                or (
-                    parent["layout"] in ("stacked", "tabbed")
-                    and len(parent["nodes"]) > 1
-                )
+                or (parent["layout"] in ("stacked", "tabbed") and len(parent["nodes"]) > 1)
             ):
                 window_properties["title"] = None
         window_properties = self.compatibility(window_properties)
